package mods.immibis.microblocks;

import cpw.mods.fml.relauncher.Side;
import cpw.mods.fml.relauncher.SideOnly;
import mods.immibis.core.api.util.Dir;
import mods.immibis.microblocks.api.EnumPartClass;
import net.minecraft.block.Block;
import net.minecraft.block.BlockGrass;
import net.minecraft.client.renderer.RenderBlocks;
import net.minecraft.util.AxisAlignedBB;

public class GrassPartType extends DefaultPartType {

	public GrassPartType(int id, EnumPartClass clazz, double size, String unlocalizedNameFormat, String unlocalizedBlockName, Block modelBlock, int modelMeta) {
		super(id, clazz, size, unlocalizedNameFormat, unlocalizedBlockName, modelBlock, modelMeta);
	}
	
	@Override
	@SideOnly(Side.CLIENT)
	protected void renderFaces(RenderBlocks rb, int bx, int by, int bz, AxisAlignedBB aabb, AxisAlignedBB rbb, boolean nx, boolean ny, boolean nz, boolean px, boolean py, boolean pz) {
		
		int grassColour =
			(rb != null)
			? Block.grass.colorMultiplier(rb.blockAccess, bx, by, bz)
			: Block.grass.getBlockColor(); // item colour
			
		double r = (grassColour >> 16 & 255) / 255.0;
        double g = (grassColour >> 8 & 255) / 255.0;
        double b = (grassColour & 255) / 255.0;
		
		boolean fancyGrass = RenderBlocks.fancyGrass && (rb == null || !rb.hasOverrideBlockTexture());
		
		tymin = 1 - tymax;
		tymax = 1;
		
		if(nz) {
			setTex(Dir.NZ);
			setBaseColour(0.8, 0.8, 0.8);
			getBrightnessZFace(rb, bx, by, bz, rbb.minZ, -1);
			rawRenderFaceNZ(aabb, rbb);
			
			if(fancyGrass) {
				setBaseColour(0.8*r, 0.8*g, 0.8*b);
				setTex(BlockGrass.getIconSideOverlay());
				rawRenderFaceNZ(aabb, rbb);
			}
		}
		
		if(ny) {
			setTex(Dir.NY);
			setBaseColour(0.5, 0.5, 0.5);
			getBrightnessYFace(rb, bx, by, bz, rbb.minY, -1);
			rawRenderFaceNY(aabb, rbb);
		}
		
		if(nx) {
			setTex(Dir.NX);
			setBaseColour(0.6, 0.6, 0.6);
			getBrightnessXFace(rb, bx, by, bz, rbb.minX, -1);
			rawRenderFaceNX(aabb, rbb);
			
			if(fancyGrass) {
				setBaseColour(0.8*r, 0.8*g, 0.8*b);
				setTex(BlockGrass.getIconSideOverlay());
				rawRenderFaceNX(aabb, rbb);
			}
		}
		
		if(pz) {
			setTex(Dir.PZ);
			setBaseColour(0.8, 0.8, 0.8);
			getBrightnessZFace(rb, bx, by, bz, rbb.maxZ, 1);
			rawRenderFacePZ(aabb, rbb);
			
			if(fancyGrass) {
				setBaseColour(0.8*r, 0.8*g, 0.8*b);
				setTex(BlockGrass.getIconSideOverlay());
				rawRenderFacePZ(aabb, rbb);
			}
		}
		
		if(py) {
			setTex(Dir.PY);
			setBaseColour(r, g, b);
			getBrightnessYFace(rb, bx, by, bz, rbb.maxY, 1);
			rawRenderFacePY(aabb, rbb);
		}
		
		if(px) {
			setTex(Dir.PX);
			setBaseColour(0.6, 0.6, 0.6);
			getBrightnessXFace(rb, bx, by, bz, rbb.maxX, 1);
			rawRenderFacePX(aabb, rbb);
			
			if(fancyGrass) {
				setBaseColour(0.8*r, 0.8*g, 0.8*b);
				setTex(BlockGrass.getIconSideOverlay());
				rawRenderFacePX(aabb, rbb);
			}
		}
	}

}
